@@ -54,11 +54,7 @@
 #'
 #'   If the size of the objects in the cache exceeds `max_size`, then objects
 #'   will be removed from the cache. Objects will be removed from the cache so
-#'   that the total size remains under `max_size`. Note that the size is
-#'   calculated using the size of the files, not the size of disk space used by
-#'   the files --- these two values can differ because of files are stored in
-#'   blocks on disk. For example, if the block size is 4096 bytes, then a file
-#'   that is one byte in size will take 4096 bytes on disk.
+#'   that the total size remains under `max_size`.
 #'
 #'   Another time that objects can be removed from the cache is when `get()` is
 #'   called. If the target object is older than `max_age`, it will be removed
@@ -98,6 +94,10 @@
 #'       Returns `TRUE` if the cache contains the key, otherwise
 #'       `FALSE`.
 #'     }
+#'     \item{`remove(key)`}{
+#'       Removes `key` from the cache, if it exists in the cache. If the key is
+#'       not in the cache, this does nothing.
+#'     }
 #'     \item{`size()`}{
 #'       Returns the number of items currently in the cache.
 #'     }
@@ -117,6 +117,9 @@
 #'     }
 #'   }
 #'
+#' @param max_size Maximum size of the cache, in bytes. If the cache exceeds
+#'   this size, cached objects will be removed according to the value of the
+#'   `evict`. Use `Inf` for no size limit. The default is 512 megabytes.
 #' @inheritParams cache_disk
 #'
 #' @return A memory caching object, with class `cache_mem`.
@@ -193,20 +196,37 @@ cache_mem <- function(
   # current column-first approach is much, much faster.
   key_idx_map_  <- fastmap()
 
-  key_          <- rep_len(NA_character_, INITIAL_SIZE)
-  value_        <- vector("list",         INITIAL_SIZE)
-  size_         <- rep_len(NA_real_,      INITIAL_SIZE)
-  mtime_        <- rep_len(NA_real_,      INITIAL_SIZE)
-  atime_        <- rep_len(NA_real_,      INITIAL_SIZE)
+  # These values are set in the reset() method.
+  key_          <- NULL
+  value_        <- NULL
+  size_         <- NULL
+  mtime_        <- NULL
+  atime_        <- NULL
 
-  total_n_      <- 0L  # Total number of items
-  total_size_   <- 0   # Total number of bytes used
-  last_idx_     <- 0L  # Most recent (and largest) index used
+  total_n_      <- NULL  # Total number of items
+  total_size_   <- NULL  # Total number of bytes used
+  last_idx_     <- NULL  # Most recent (and largest) index used
 
 
   # ============================================================================
   # Public methods
   # ============================================================================
+
+  reset <- function() {
+    log_(paste0('reset'))
+    key_idx_map_$reset()
+    key_        <<- rep_len(NA_character_, INITIAL_SIZE)
+    value_      <<- vector("list",         INITIAL_SIZE)
+    size_       <<- rep_len(NA_real_,      INITIAL_SIZE)
+    mtime_      <<- rep_len(NA_real_,      INITIAL_SIZE)
+    atime_      <<- rep_len(NA_real_,      INITIAL_SIZE)
+
+    total_n_    <<- 0L
+    total_size_ <<- 0
+    last_idx_   <<- 0L
+    invisible(TRUE)
+  }
+
   get <- function(key, missing = missing_) {
     log_(paste0('get: key "', key, '"'))
     validate_key(key)
@@ -358,12 +378,6 @@ cache_mem <- function(
     invisible(TRUE)
   }
 
-  reset <- function() {
-    log_(paste0('reset'))
-    key_idx_map_$reset()
-    invisible(TRUE)
-  }
-
   prune <- function() {
     log_(paste0('prune'))
 
@@ -611,6 +625,9 @@ cache_mem <- function(
     cat(text, sep = "\n", file = logfile_, append = TRUE)
   }
 
+
+  reset()
+
   # ============================================================================
   # Returned object
   # ============================================================================
